@@ -29,7 +29,9 @@ from ...bluebase import (
     )
 from ...motv import Customer
 import requests
+import datetime
 import json
+import redis
 
 
 @api.route('/sms/customer/all', methods=['GET'])
@@ -662,8 +664,11 @@ def ussdCustomerSaveInvoice(login):
                     "moins"
                     )
                 LOGS.logger.info("Account new: "+json.dumps(account_new))
+                transaction_status = "Transaction en attente"
+                transaction_status = "Activation en attente"
                 if account_new["status"] == 200:
                     # Activation du produit
+                    transaction_status = "Transaction validée"
                     data = {
                         'session': '',
                         "operator": "bip",
@@ -680,6 +685,7 @@ def ussdCustomerSaveInvoice(login):
                     response = izytv_buy_recharge(data)
                     # Activation offre NON OK
                     if response["status"] != 200:
+                        activation_status = "Echec d'activation"
                         response = {
                             "code": "044-05-{}".format(
                                 response["status"]
@@ -697,6 +703,7 @@ def ussdCustomerSaveInvoice(login):
                         }
                         send_sms(data_sms)
                         # Roll back du solde du client
+                        transaction_status = "Roll back du solde"
                         account_new = update_balance(
                             params["caller_num"],
                             int(float(params["amount"])),
@@ -706,6 +713,7 @@ def ussdCustomerSaveInvoice(login):
                         LOGS.logger.info(account_new)
                     # Activation offre OK
                     elif response["status"] == 200:
+                        activation_status = "Activation reussie"
                         response = {
                             "code": "044-05-200",
                             "info": "Activation du produit",
@@ -720,6 +728,7 @@ def ussdCustomerSaveInvoice(login):
                             }
                         send_sms(data_sms)
                 else:
+                    transaction_status = "Echec de transaction"
                     message = MESSAGE[lg]["400"]
                     data_sms = {
                         "msisdn": params["caller_num"],
@@ -728,6 +737,30 @@ def ussdCustomerSaveInvoice(login):
                     send_sms(data_sms)
                     response = account_new
                     LOGS.logger.info(response)
+
+                # Enregistrement redis
+                re = redis.Redis(db=6)
+                mydate = datetime.datetime.today()
+                transaction_date = mydate.strftime("%Y-%m-%d %H:%M:%S")
+                redis_key = "request:payment:{}".format(request_id)
+                data_redis = {
+                    'operation_id': request_id,
+                    'info': activation_status,
+                    'partner_ref': request_id,
+                    'TransactionDate': transaction_date,
+                    'caller_num': params['caller_num'],
+                    'label': params['bundle_name'],
+                    'operator': 'ussd-bip',
+                    'status': transaction_status,
+                    'service_type': 'izytv',
+                    'offre_refnum': params['offer_id'],
+                    'amount': params['amount'],
+                    'client_refnum': customer['message']['client_refnum'],
+                    'other': params['device_name'],
+                    'device_id': login
+                    }
+                re.hmset(redis_key, data_redis)
+                LOGS.logger.info("Enregistrement redis OK")
             else:
                 message = MESSAGE[lg]["400"]
                 data_sms = {"msisdn": params["caller_num"], "message": message}
